@@ -7,7 +7,7 @@ use Webqq::Client::Cache;
 use Webqq::Message::Queue;
 
 #定义模块的版本号
-our $VERSION = "4.6";
+our $VERSION = "4.7";
 
 use LWP::UserAgent;#同步HTTP请求客户端
 use AnyEvent::UserAgent;#异步HTTP请求客户端
@@ -220,7 +220,7 @@ sub relogin{
     #停止心跳请求
     undef $self->{timer_heartbeat};
     #重新设置一个心跳请求
-    $self->{timer_heartbeat} = AE::timer 0 , 60 , sub{ $self->_get_msg_tip()};
+    #$self->{timer_heartbeat} = AE::timer 0 , 60 , sub{ $self->_get_msg_tip()};
     #$self->{cache_for_uin_to_qq} = Webqq::Client::Cache->new;
     #$self->{cache_for_group_sig} = Webqq::Client::Cache->new;
     $self->login(qq=>$self->{default_qq_param}{qq},pwd=>$self->{default_qq_param}{pwd});
